package com.codigoparallevar.minicards;

import android.support.design.widget.FloatingActionButton;
import android.support.design.widget.Snackbar;
import android.support.v7.app.ActionBar;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.MotionEvent;
import android.view.View;

import com.codigoparallevar.minicards.parts.buttons.RoundButton;

public class MainActivity extends AppCompatActivity {

    CanvasView canvasView;
    com.getbase.floatingactionbutton.AddFloatingActionButton AddPartButton;
    com.getbase.floatingactionbutton.FloatingActionButton SetDevModeButton;
    com.getbase.floatingactionbutton.FloatingActionButton SetUserModeButton;

    com.getbase.floatingactionbutton.FloatingActionsMenu devFabMenu;
    com.getbase.floatingactionbutton.FloatingActionsMenu userFabMenu;

    boolean devMode = false;
    FloatingActionButton removePartFab;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        // Hide action bar
        ActionBar actionBar = getSupportActionBar();
        if (actionBar != null) {
            actionBar.hide();
        }

        setContentView(R.layout.activity_main);

        // Use manually controlled canvas
        canvasView = (CanvasView) findViewById(R.id.canvasView);
        canvasView.setParentActivity(this);

        removePartFab = (FloatingActionButton) findViewById(R.id.remove_part_fab);
        canvasView.setDropZone(
                removePartFab.getX(), removePartFab.getX() + removePartFab.getWidth(),
                removePartFab.getY(), removePartFab.getY() + removePartFab.getHeight());

        // Set callbacks to fab buttons
        devFabMenu = (com.getbase.floatingactionbutton.FloatingActionsMenu)
                findViewById(R.id.dev_mode_fab);
        userFabMenu = (com.getbase.floatingactionbutton.FloatingActionsMenu)
                findViewById(R.id.user_mode_fab);

        AddPartButton = (com.getbase.floatingactionbutton.AddFloatingActionButton)
                findViewById(R.id.add_part_button);
        AddPartButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (canvasView != null) {
                    canvasView.addPart(new RoundButton(500, 500, 50, 100));
                }
            }
        });

        SetDevModeButton = (com.getbase.floatingactionbutton.FloatingActionButton)
                findViewById(R.id.set_developer_mode_button);
        SetDevModeButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                MainActivity.this.setDevMode(true);
            }
        });

        SetUserModeButton = (com.getbase.floatingactionbutton.FloatingActionButton)
                findViewById(R.id.set_user_mode_button);
        SetUserModeButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                MainActivity.this.setDevMode(false);
            }
        });

        setDevMode(devMode);
    }

    private void setDevMode(boolean goToDevMode) {
        boolean willInvalidate = devMode != goToDevMode;

        devMode = goToDevMode;
        if (goToDevMode){
            devFabMenu.setVisibility(View.VISIBLE);
            userFabMenu.setVisibility(View.GONE);
        }
        else {
            devFabMenu.setVisibility(View.GONE);
            userFabMenu.setVisibility(View.VISIBLE);
        }

        this.canvasView.setDevMode(devMode);

        if (willInvalidate){
            invalidate();
        }
    }

    @Override
    public boolean onTouchEvent(MotionEvent event) {
        if (canvasView != null){
            return canvasView.onTouchEvent(event);
        }

        Log.e("MainActivity", "CanvasView is null");

        return super.onTouchEvent(event);
    }

    public void invalidate() {
        if (canvasView != null){
            if (canvasView.isDragging()){
                devFabMenu.setVisibility(View.GONE);
                userFabMenu.setVisibility(View.GONE);
                removePartFab.setVisibility(View.VISIBLE);
                Log.d("Main", "Changing visibility!");
            }
            else {
                this.setDevMode(devMode);
                removePartFab.setVisibility(View.GONE);
                Log.d("Main", "Now changing visibility!");
            }
            canvasView.setDropZone(
                    removePartFab.getX(), removePartFab.getX() + removePartFab.getWidth(),
                    removePartFab.getY(), removePartFab.getY() + removePartFab.getHeight());
        }
    }
}
